@@ -164,8 +164,9 @@ size_t gran_to_bytes(enum write_granularity);
 #define FEATURE_SET_READ_PARAMS	(1u << 31) /**< SRP instruction 0xc0 for dummy cycles and burst length */
 
 /* Multi-I/O Shorthands */
-#define FEATURE_QIO		(FEATURE_FAST_READ | \
-				 FEATURE_FAST_READ_DOUT | FEATURE_FAST_READ_DIO | \
+#define FEATURE_DIO		(FEATURE_FAST_READ | \
+				 FEATURE_FAST_READ_DOUT | FEATURE_FAST_READ_DIO)
+#define FEATURE_QIO		(FEATURE_DIO | \
 				 FEATURE_FAST_READ_QOUT | FEATURE_FAST_READ_QIO)
 #define FEATURE_QPI_35		(FEATURE_QIO | FEATURE_QPI_35_F5)
 #define FEATURE_QPI_38		(FEATURE_QIO | FEATURE_QPI_38_FF)
@@ -278,6 +279,7 @@ struct flashchip {
 		/* SPI25 is very common. Keep it at zero so we don't have
 		   to specify it for each and every chip in the database.*/
 		SPI25 = 0,
+		SPI25_EEPROM,
 		SPI95,
 		SPI_EDI,
 	} spi_cmd_set;
@@ -453,6 +455,7 @@ struct flashprog_flashctx {
 		bool force_boardmismatch;
 		bool verify_after_write;
 		bool verify_whole_chip;
+		bool non_volatile_wrsr;
 	} flags;
 	/* We cache the state of the extended address register (highest byte
            of a 4BA for 3BA instructions) and the state of the 4BA mode here.
@@ -540,6 +543,7 @@ int flashprog_read_range(struct flashctx *, uint8_t *buf, unsigned int start, un
 int verify_range(struct flashctx *flash, const uint8_t *cmpbuf, unsigned int start, unsigned int len);
 void emergency_help_message(void);
 void list_programmers_linebreak(int startcol, int cols, int paren);
+int selfcheck_chip(const struct flashchip *, int idx);
 int selfcheck(void);
 int read_buf_from_file(unsigned char *buf, unsigned long size, const char *filename);
 int write_buf_to_file(const unsigned char *buf, unsigned long size, const char *filename);
@@ -564,11 +568,6 @@ int register_chip_restore(chip_restore_fn_cb_t func, struct flashctx *flash, uin
 void print_chip_support_status(const struct flashchip *chip);
 
 /* cli_output.c */
-extern enum flashprog_log_level verbose_screen;
-extern enum flashprog_log_level verbose_logfile;
-int open_logfile(const char * const filename);
-int close_logfile(void);
-void start_logging(void);
 int flashprog_print_cb(enum flashprog_log_level level, const char *fmt, va_list ap);
 void flashprog_progress_cb(enum flashprog_progress_stage, size_t current, size_t total, void *user_data);
 /* Let gcc and clang check for correct printf-style format strings. */
